@@ -1,6 +1,6 @@
 import pptx
 
-from .utils import BaseParser
+from convertextract.parsers.utils import BaseParser
 
 class Parser(BaseParser):
     """Extract text from pptx file using python-pptx
